@@ -1,7 +1,7 @@
 package Mail::Identity;
 use vars '$VERSION';
-$VERSION = '0.06';
-use base 'User::Identity::Collection::Item';
+$VERSION = '0.07';
+use base 'User::Identity::Item';
 
 use strict;
 use warnings;
@@ -10,6 +10,9 @@ use User::Identity;
 use Scalar::Util 'weaken';
 
 
+sub type() { "email" }
+
+
 sub init($)
 {   my ($self, $args) = @_;
 
@@ -28,8 +31,6 @@ sub init($)
    $self;
 }
 
-#-----------------------------------------
-
 
 sub from($)
 {   my ($class, $other) = @_;
@@ -53,9 +54,6 @@ sub from($)
 }
 
 
-#-----------------------------------------
-
-
 sub comment($)
 {   my $self = shift;
     return $self->{MI_comment} = shift if @_;
@@ -66,8 +64,6 @@ sub comment($)
     $self->phrase eq $full ? undef : $full;
 }
 
-#-----------------------------------------
-
 
 sub charset()
 {   my $self = shift;
@@ -77,8 +73,6 @@ sub charset()
     $user->charset;
 }
 
-#-----------------------------------------
-
 
 sub language()
 {   my $self = shift;
@@ -89,8 +83,6 @@ sub language()
     $user->language;
 }
 
-#-----------------------------------------
-
 
 sub domain()
 {   my $self = shift;
@@ -101,8 +93,6 @@ sub domain()
     $address =~ s/.*?\@// ? $address : undef;
 }
 
-#-----------------------------------------
-
 
 sub address()
 {   my $self = shift;
@@ -118,8 +108,6 @@ sub address()
     defined $user ? $user->nickname : $name;
 }
 
-#-----------------------------------------
-
 
 sub location()
 {   my $self      = shift;
@@ -138,8 +126,6 @@ sub location()
     $location;
 }
 
-#-----------------------------------------
-
 
 sub organization()
 {   my $self = shift;
@@ -151,24 +137,17 @@ sub organization()
 }
 
 #pgp_key
-#-----------------------------------------
-
 
 sub phrase()
 {  my $self = shift;
     return $self->{MI_phrase} if defined $self->{MI_phrase};
-
     my $user = $self->user     or return undef;
     my $full = $user->fullName or return undef;
     $full;
 }
 
-#-----------------------------------------
-
 #signature
 
-#-----------------------------------------
-
 
 sub username()
 {   my $self = shift;
@@ -183,7 +162,5 @@ sub username()
     $user->nickname;
 }
 
-#-----------------------------------------
-
 1;
 
