@@ -1,6 +1,6 @@
 package User::Identity::Collection::Locations;
 use vars '$VERSION';
-$VERSION = '0.06';
+$VERSION = '0.07';
 use base 'User::Identity::Collection';
 
 use strict;
@@ -25,7 +25,7 @@ sub init($)
     $self;
 }
 
-#-----------------------------------------
+sub type() { 'whereabouts' }
 
 1;
 
