@@ -1,7 +1,7 @@
 package User::Identity::System;
 use vars '$VERSION';
-$VERSION = '0.06';
-use base 'User::Identity::Collection::Item';
+$VERSION = '0.07';
+use base 'User::Identity::Item';
 
 use strict;
 use warnings;
@@ -10,6 +10,9 @@ use User::Identity;
 use Scalar::Util 'weaken';
 
 
+sub type { "network" }
+
+
 sub init($)
 {   my ($self, $args) = @_;
 
@@ -21,30 +24,19 @@ sub init($)
    $self;
 }
 
-#-----------------------------------------
-
 
 sub hostname() { shift->{UIS_hostname} }
 
-#-----------------------------------------
-
 
 sub username() { shift->{UIS_username} }
 
-#-----------------------------------------
-
 
 sub os() { shift->{UIS_os} }
 
-#-----------------------------------------
-
 
 sub password() { shift->{UIS_password} }
 
 
-#-----------------------------------------
-
-
 sub location()
 {   my $self      = shift;
     my $location  = $self->{MI_location} or return;
